/******************************************************************************
** File Name           : $RCSfile: vpx.h $
** Short Description   : Interface to extension toolkit
** Original Project    : VideoPort Professional, MS801/MS802
** Compiler, Version   : Borland C++ 3.1,4.0,4.52, Visual C++ 1.0,1.51,
**                       Watcom C++ 9.5, 10.0
** Compiler Options    : Optimize for speed
** Libraries Used      : none
** Original Author     : Roar Lauritzsen
** Created (date)      : 1995/01/16
** Last modified by    : $Author: Roar_Lauritzsen.NO.MRT $
** Last modified (date): $Date: 1996/10/15 08:27:22 $
** Current revision    : $Revision: 1.13 $ ($Name: $)
******************************************************************************/
#ifndef _VPX_H
#define _VPX_H

#define VPX_DEFAULT 0

#include <windows.h>
#include <stdlib.h>
#include <string.h>
#include <stdio.h>
#include "vpptools.h"
#include "dialog.h"

#ifdef __cplusplus
extern "C" {
#endif

/******************************************************************************
** The following Compiler macros affect the compilation of the module:
**
** VPX_NO_MESSAGES   : Disables error MessageBoxes
** VPX_NO_DIALOG     : Disables format dialog box
** VPP_NO_DLL        : Define this macro if you are not compiling the toolkit
**                     as a DLL but you are compiling another DLL which
**                     includes the toolkit.
**
** The following macros must NOT be defined when compiling this module:
**
** VPP_NO_MONO4, VPP_NO_MONO, VPP_NO_RGB8, VPP_NO_BGR24, VPP_NO_FLASH
******************************************************************************/
/* !! Define your macros here or in your project macro definitions !!        */


typedef struct {
  VPP_VideoStandard   videoStandard;
  VPP_SignalType      signalType;
  int                 inputChannel;
  int                 brightness;
  int                 contrast;
  int                 saturation;
  float               gamma;
  int                 hue;
  VPP_SnapData        snapDataNTSC;
  VPP_SnapData        snapDataPAL;
  VPP_ReadoutMode     outputFormat;
  VPP_Bool            extTrigSnap;
  VPP_Bool            flashSnap;
  VPP_Bool            extTrigEnable;
  VPP_Bool            flashEnable;
  VPP_Bool            mono4Enable;
  VPP_Bool            monoEnable;
  VPP_Bool            RGB8Enable;
  VPP_Bool            BGR24Enable;
#ifdef __WIN32__
  VPP_Bool            RGB15Enable;
  VPP_Bool            RGB16Enable;
  VPP_Bool            BGR032Enable;
#endif
} VPX_Config;

typedef struct {
  VPP_Byte            width;
  VPP_Byte            height;
  int                 divideBy;
  VPP_Bool            doAbs;
  VPP_Char            *coeff;
} VPX_Filter;

#define VPX_AVERAGE    1
#define VPX_SMOOTH     2
#define VPX_DETAIL     3
#define VPX_SHARPEN    4
#define VPX_AI         5
#define VPX_AISHARPEN  6
#define VPX_VERTLINES  7
#define VPX_HORIZLINES 8

VPP_Errno EXTERN
VPX_defaultConfig (VPX_Config VPP_far *config);

VPP_Errno EXTERN
VPX_prepare (VPX_Config VPP_far *config, VPP_Bool forceConfig);

VPP_Errno EXTERN
VPX_snap (VPX_Config VPP_far *config);

VPP_Errno EXTERN
VPX_draw (HDC hdc, VPX_Config VPP_far *config,
			 VPP_Word xPos, VPP_Word yPos, VPP_Word xSize, VPP_Word ySize);

VPP_Errno EXTERN
VPX_drawDIB (HDC hdc, HGLOBAL hdib,
			 VPP_Word xPos, VPP_Word yPos, VPP_Word xSize, VPP_Word ySize);

VPP_Errno EXTERN
VPX_readoutDIB(VPX_Config VPP_far *config, HGLOBAL VPP_far *phdib);

VPP_Errno EXTERN
VPX_readoutDIBToClipboard(VPX_Config VPP_far *config);

VPP_Errno EXTERN
VPX_saveDIBToClipboard(HGLOBAL hDIB);

VPP_Errno EXTERN
VPX_readoutDIBToFile(VPX_Config VPP_far *config, char VPP_far *filename);

VPP_Errno EXTERN
VPX_saveDIBToFile(HGLOBAL hDIB, char VPP_far *filename);

VPP_Errno EXTERN
VPX_snapAverageDIB(VPX_Config VPP_far *config, HGLOBAL VPP_far *phdib,
	VPP_Byte numAverage, VPP_Byte divideBy);

VPP_Errno EXTERN
VPX_filterDIB(HGLOBAL hDib, VPX_Filter VPP_far *filter);

VPX_Filter VPP_far * EXTERN
VPX_getFilter(int filterNo);

VPP_Errno EXTERN
VPX_copyDIB(HANDLE hDIB, HANDLE VPP_far *phDIB);

VPP_Errno EXTERN
VPX_readIniFile (char VPP_far *filename, char VPP_far *sectionname,
					  VPX_Config VPP_far *config);

VPP_Errno EXTERN
VPX_saveIniFile (char VPP_far *filename, char VPP_far *sectionname,
					  VPX_Config VPP_far *config);

VPP_Errno EXTERN
VPX_defaultPalette (HDC hdc, VPP_Bool monochrome);

VPP_Errno EXTERN
VPX_releasePalette (void);

#ifndef VPX_NO_DIALOG
int EXTERN
VPX_formatDialogBox (HINSTANCE hinst, HWND parent, VPX_Config VPP_far *config);
#endif

#ifdef __cplusplus
}
#endif

#endif /* _VPX_H */

